@@ -6,7 +6,7 @@ Swagger2 - Swagger RESTful API Documentation
 
 =head1 VERSION
 
-0.66
+0.67
 
 =head1 DESCRIPTION
 
@@ -62,7 +62,7 @@ use File::Basename ();
 use File::Spec;
 use Swagger2::SchemaValidator;
 
-our $VERSION = '0.66';
+our $VERSION = '0.67';
 
 # Should be considered internal
 our $SPEC_FILE = File::Spec->catfile(File::Basename::dirname(__FILE__), 'Swagger2', 'schema.json');
@@ -200,7 +200,8 @@ sub new {
   my $self  = $class->SUPER::new(@_);
 
   $url =~ s!^file://!!;
-  $self->{url} = Mojo::URL->new($url);
+  $self->{url} ||= $url;
+  $self->{url} = Mojo::URL->new($self->{url}) unless ref $self->{url};
   $self;
 }
 
@@ -266,7 +267,7 @@ sub to_string {
   @errors = $self->validate;
 
 Will validate L</api_spec> against
-L<Swagger RESTful API Documentation Specification/https://github.com/swagger-api/swagger-spec/blob/master/versions/2.0.md>,
+L<Swagger RESTful API Documentation Specification|https://github.com/swagger-api/swagger-spec/blob/master/versions/2.0.md>,
 and return a list with all the errors found. See also L<JSON::Validator/validate>.
 
 =cut
